# Prelude-Trigger, (C) 2009 Alexander Tsvyashchenko <prelude@ndl.kiev.ua>
# Based on Prelude-Correlator, Copyright (C) 2009 PreludeIDS Technologies.
# Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

import pkg_resources, sys, os, traceback, ConfigParser


class PluginLog:
    def __init__(self, env):
        self.__logger = env.logger
        self.__prefix = "[" + self.__class__.__name__ + "]: "

    def debug(self, log):
        self.__logger.debug(self.__prefix + log)

    def info(self, log):
        self.__logger.info(self.__prefix + log)

    def warning(self, log):
        self.__logger.warning(self.__prefix + log)

    def error(self, log):
        self.__logger.error(self.__prefix + log)

    def critical(self, log):
        self.__logger.critical(self.__prefix + log)


class Plugin(object, PluginLog):

    def __init__(self, env):
        self.env = env
        PluginLog.__init__(self, env)

class FilterPlugin(Plugin):
    def filter(self, filter, idmef):
        pass

class ActionPlugin(Plugin):
    def execute(self, action, idmef):
        pass

class PluginManager:
    __ENTRYPOINT = 'PreludeTrigger.plugins'

    def __init__(self, env):
	self._env = env
        self.__filters = {}
        self.__actions = {}

        for entrypoint in pkg_resources.iter_entry_points(self.__ENTRYPOINT):
            plugin_class = entrypoint.load()
            pname = plugin_class.__name__
            try:
                pi = plugin_class(env)
            except Exception, e:
                env.logger.error("Exception occurred while loading %s: %s" % (pname, e))
                continue

	    if isinstance(pi, FilterPlugin):
	        self.__filters[pname] = pi
	    elif isinstance(pi, ActionPlugin):
	        self.__actions[pname] = pi
	    else:
	        env.logger.error("Unrecognized plugin type for plugin %s" % pname)

    def getFilterPluginCount(self):
        return len(self.__filters)
    
    def getActionPluginCount(self):
        return len(self.__actions)

    def run(self, trigger, idmef):
	executed = False

        try:
	    matched = True
	    if 'filters' in trigger:
	        for filter in trigger['filters']:
                    if filter['plugin'] in self.__filters:
	                if not self.__filters[filter['plugin']].filter(filter, idmef):
		            matched = False
			    break
	            else:
	                self._env.logger.error("Unrecognized filter plugin name %s" % filter['plugin'])

	    if matched:
	        for action in trigger['actions']:
	            if action['plugin'] in self.__actions:
		        self.__actions[action['plugin']].execute(action, idmef)
			executed = True
	            else:
	                self._env.logger.error("Unrecognized action plugin name %s" % action['plugin'])
        except Exception, e:
            traceback.print_exc()

	return executed
