#!/usr/bin/env python

from ez_setup import use_setuptools
use_setuptools()

import os, sys, shutil
from setuptools import setup, find_packages
from setuptools.command.install import install
from setuptools.command.sdist import sdist

PRELUDE_TRIGGER_VERSION = "1.0.0-beta1"

class my_install(install):
        def __install_data(self):
                data_files = self.distribution.data_files
                self.distribution.data_files = []

                if self.prefix == "/usr":
                        prefix = ""
                else:
                        prefix = self.prefix or ""

                root = self.root or ""
                for dir, files in data_files:
                        dir = os.path.abspath(os.path.join(root, prefix, dir))

                        self.mkpath(dir)
                        for f in files:
                                dest = os.path.join(dir, os.path.basename(f))
                                if dest[-4:] == "conf" and os.path.exists(dest):
                                        dest += "-dist"

                                self.copy_file(f, dest)

        def run(self):
                prefix = self.prefix
                if prefix == "/usr":
                        prefix = ""

                self.init_siteconfig(prefix)
                self.__install_data()
                install.run(self)
                os.remove("PreludeTrigger/siteconfig.py")

        def init_siteconfig(self, prefix):
                config = open("PreludeTrigger/siteconfig.py", "w")
                print >> config, "conf_dir = '%s'" % os.path.abspath(prefix + "/etc/prelude-trigger")
                config.close()


is_egg = "bdist_egg" in sys.argv
if is_egg:
        # Make sure we remove any trace of siteconfig.py
        try: shutil.rmtree("build")
        except: pass
        package_data = { '': [ "*.dat"] }
        data_files = [ ("", ["prelude-trigger.yaml"]) ]
else:
        package_data = {}
        data_files = [ ("etc/prelude-trigger", ["prelude-trigger.yaml"]) ]

setup(
        name="prelude-trigger",
        version=PRELUDE_TRIGGER_VERSION,
        maintainer = "Alexander Tsvyashchenko",
        maintainer_email = "prelude@ndl.kiev.ua",
        author = "Alexander Tsvyashchenko",
        author_email = "prelude@ndl.kiev.ua",
        url = "http://www.ndl.kiev.ua/content/projects/prelude-trigger",
        download_url = "http://www.ndl.kiev.ua/content/projects/prelude-trigger",
        description = "Prelude-Trigger fires actions based on events received by Prelude",
        long_description = """
Prelude-Trigger fires actions based on events received by Prelude.

Triggers are fired based on single IDMEF event, if you need to fire actions
based on multiple events - use Prelude-Correlator to combine them to
single correlation event first.

Prelude-Trigger contains implementation of regex-based filtering and
external command execution with IDMEF arguments support, but you may
easily write new plugins with different filtering and execution
behavior in Python language.
""",
        classifiers = [ "Development Status :: 3 - Alpha",
                        "Environment :: Console",
                        "Intended Audience :: System Administrators",
                        "License :: OSI Approved :: GNU General Public License (GPL)",
                        "Natural Language :: English",
                        "Operating System :: OS Independent",
                        "Programming Language :: Python",
                        "Topic :: Security",
                        "Topic :: System :: Monitoring" ],

        packages = find_packages(),
        entry_points = {
                'console_scripts': [
                        'prelude-trigger = PreludeTrigger.main:main',
                ],

                'PreludeTrigger.plugins': [
                        'RegexMatch = PreludeTrigger.plugins.regexmatch:RegexMatch',
                        'RunCommand = PreludeTrigger.plugins.runcommand:RunCommand'
                ]
        },

        zip_safe = False,
        data_files = data_files,
        package_data = package_data,

        cmdclass = { 'install': my_install }
)
